@@ -1,3 +1,3 @@
 # Exports package resources so users can use in their own project.
-__all__ = ['FernetEnc']
+__all__ = ['FernetEnc', 'FernetEncGUI']
 from .fernetenc import *
\ No newline at end of file
